==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/EnvVarBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvVarBuilder extends EnvVarFluentImpl<EnvVarBuilder> implements VisitableBuilder<EnvVar,EnvVarBuilder>{
  public EnvVarBuilder() {
    this(false);
  }
  public EnvVarBuilder(Boolean validationEnabled) {
    this(new EnvVar(), validationEnabled);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvVar(), validationEnabled);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent,EnvVar instance) {
    this(fluent, instance, false);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent,EnvVar instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withValue(instance.getValue());
      fluent.withValueFrom(instance.getValueFrom());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvVarBuilder(EnvVar instance) {
    this(instance,false);
  }
  public EnvVarBuilder(EnvVar instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withValue(instance.getValue());
      this.withValueFrom(instance.getValueFrom());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvVarFluent<?> fluent;
  Boolean validationEnabled;
  public EnvVar build() {
    EnvVar buildable = new EnvVar(fluent.getName(),fluent.getValue(),fluent.getValueFrom());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/EnvVarBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvVarBuilder extends EnvVarFluent<EnvVarBuilder> implements VisitableBuilder<EnvVar,EnvVarBuilder>{
  public EnvVarBuilder() {
    this(false);
  }
  public EnvVarBuilder(Boolean validationEnabled) {
    this(new EnvVar(), validationEnabled);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvVar(), validationEnabled);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent,EnvVar instance) {
    this(fluent, instance, false);
  }
  public EnvVarBuilder(EnvVarFluent<?> fluent,EnvVar instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvVar());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withValue(instance.getValue());
      fluent.withValueFrom(instance.getValueFrom());
      fluent.withName(instance.getName());
      fluent.withValue(instance.getValue());
      fluent.withValueFrom(instance.getValueFrom());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvVarBuilder(EnvVar instance) {
    this(instance,false);
  }
  public EnvVarBuilder(EnvVar instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvVar());

    if (instance != null) {
      this.withName(instance.getName());
      this.withValue(instance.getValue());
      this.withValueFrom(instance.getValueFrom());
      this.withName(instance.getName());
      this.withValue(instance.getValue());
      this.withValueFrom(instance.getValueFrom());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvVarFluent<?> fluent;
  Boolean validationEnabled;
  public EnvVar build() {
    EnvVar buildable = new EnvVar(fluent.getName(),fluent.getValue(),fluent.buildValueFrom());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
